{% load static %}<!DOCTYPE 5><html lang="en"><head><title></title><link rel="stylesheet" href="https://cdn.rawgit.com/appknox/bohemia/master/dist/bohemia.css"/><link rel="stylesheet" href="report.css"/></head><body><div class="main-container"><div class="report-container"><div class="columns margin-top20"><div class="column"><h5>confidential</h5></div><div class="column content-right"><h5>15th February, 2017</h5></div></div><div class="columns margin-top50"><div class="column align-middle"><img src="https://raw.githubusercontent.com/appknox/press-kit/master/logo/logo-dark-small.png"/></div></div><div class="columns margin-top100"><div class="column align-middle"><h2 class="underline">Android Security Report</h2></div></div><div class="columns margin-top10"><div class="column align-middle"><h6 class="italics">For Internal Purpose</h6></div></div><div class="columns margin-top50"><div class="column align-middle"><h5 class="bold">Prepared For: {{file.name}}</h5></div></div><div class="columns margin-top50"><div class="column"><div class="mini-container"><p>Prepared by XYSec Labs Pte. Ltd. Portions of this document and the templates used in its production are the property of XYSec Labs Pte. Ltd. and cannot be copied without permission.</p><p>While precautions have been taken in the preparation of this document, XYSec Labs Pte. Ltd., the publisher, and the author(s) assume no responsibility for errors, omissions, or for damages resulting from the use of the information contained herein. Use of XYSec Labs Pte. Ltd. services does not guarantee the security of a system, or that intrusions will not occur.</p></div></div></div><div class="columns"><div class="column heading-container flex-center"><h3>Table Of Contents</h3></div></div><div class="columns"><div class="column is-half margin-auto"><div class="content-main-table"><div class="content-table"><ol class="main-heading"><li><a href="#01">Report Summary</a></li><ol class="sub-topic"><li><a href="#02">Application Details</a></li><li><a href="#03">Audit Summary</a></li><li><a href="#04">Appknox Security Rating</a></li></ol></ol></div>{% for analysis in file.analyses.all %}
{% if analysis.risk > RiskEnum.NONE %}<div class="content-table"><ol class="main-heading"><li><a href="#{{ analysis.id }}">{{ analysis.vulnerability.heading }}</a></li></ol>{% for subheading in analysis.vulnerability.sub_headings.all %}<ol class="sub-topic"><li><a href="#{{ analysis.id }}{{ forloop.counter }}">{{ subheading.heading }}</a></li></ol>{% endfor %}
{% if analysis.vulnerability.non_compliant %}<ol class="sub-topic"><li><a href="#{{ analysis.id }}{{ forloop.counter }}non_compliant">Noncompliant Code Example</a></li></ol>{% endif %}
{% if analysis.vulnerability.compliant %}<ol class="sub-topic"><li><a href="#{{ analysis.id }}{{ forloop.counter }}compliant">Compliant Solution</a></li></ol>{% endif %}
{% if analysis.vulnerability.related_to %}<ol class="sub-topic"><li><a href="#{{ analysis.id }}{{ forloop.counter }}related_to">Related Vulnerabilities</a></li></ol>{% endif %}
{% if analysis.vulnerability.business_implication %}<ol class="sub-topic"><li><a href="#{{ analysis.id }}{{ forloop.counter }}business_implication">Business Implication</a></li></ol>{% endif %}</div>{% endif %}
{% endfor %}</div></div></div><div class="report-summary"><div class="columns"><div class="column heading-container flex-center"><a class="link-tag" id="01"></a><h3>Report Summary</h3></div><p class="margin-left30">Appknox conducted a security assessment of the mobile application for the Android platform. This report contains all the findings during the automated auditing process. It also contains the process of discovering those vulnerabilities in the first place, and ways to remediate those issues.</p></div><div class="columns"><div class="column sub-heading-container flex-center"><a class="link-tag" id="02"></a><h5>Application Details</h5></div></div><table><tr><td>Application Name</td><td>{{file.name}}</td></tr><tr><td>Application Namespace</td><td>{{file.name}}</td></tr><tr><td>Version</td><td>{{file.version}}</td></tr><tr><td>Audit Date</td><td>{{file.updated_on}}</td></tr><tr><td>Application SHA1 Hash</td><td>{{file.sha1hash}}</td></tr><tr><td>Application MD5 Hash</td><td>{{file.md5hash}}</td></tr></table></div><div class="columns"><div class="column sub-heading-container flex-center"><a class="link-tag" id="03"></a><h5>Audit Summary</h5></div></div><table class="audit-table">{% for analysis in file.analyses.all %}<tr><td><h5>{{ analysis.vulnerability.name }}</h5><p>{{ analysis.vulnerability.description }}</p></td><td class="risk-type"><h5 class="tag" style="background-color:{{ analysis.color }};color:#FFF;">{% if analysis.risk == RiskEnum.NONE %}
Passed
{% else %}
{{ analysis.get_risk_display }} Risk
{% endif %}</h5></td></tr>{% endfor %}</table><div class="margin-top50"><table class="audit-table"><tr><td>Priority Level</td><td>Number of failed test cases</td></tr><tr><td>High Risk</td><td>{# audit_summary | hash:RiskEnum.HIGH #}</td></tr><tr><td>Medium Risk</td><td>{# audit_summary | hash:RiskEnum.MEDIUM #}</td></tr><tr><td>Low Risk</td><td>{# audit_summary | hash:RiskEnum.LOW #}</td></tr></table></div><section><div class="columns"><div class="column sub-heading-container flex-center"><a class="link-tag" id="04"></a><h5>Appknox Security Rating</h5></div></div><div style="text-align:center;" id="logo"><img class="images" width="316" height="75" src="{{ chart_url }}"/></div><p>Appknox Security Rating:<b>{# audit_summary | hash:AUDIT_SUMMARY_RATING #}
Unsecured</b></p></section>{% for analysis in file.analyses.all %}
{% if analysis.risk > RiskEnum.NONE %}<section><div class="columns"><div class="column heading-container flex-center"><a class="link-tag" id="{{ analysis.id }}"></a><h3>{{ analysis.vulnerability.heading }}</h3></div></div><div class="columns"><div class="column margin-left35 margin-top50 margin-bottom50"><h5 class="tag risk-tag" style="background-color:{{ analysis.color }};color:#FFF;">Risk Rating : {{ analysis.get_risk_display }}</h5></div></div><div class="columns"><div class="column analysis-type"><a class="link-tag" id="09"></a><h5>Risk Assessment</h5></div></div><p class="margin-left35 margin-top20">{{ analysis.vulnerability.description | safe }}</p>{% for descriptions in analysis.description %}
{% if descriptions.extra_description %}<p>{{ descriptions.extra_description | safe }}</p>{% endif %}<pre class="pre-code margin-left50 margin-top20 margin-bottom50">{{ descriptions.description | safe }}</pre>{% endfor %}
{% for subheading in analysis.vulnerability.sub_headings.all %}<h3 id="title"><a id="{{ analysis.id }}{{ forloop.counter }}">{{ subheading.heading }}</a>{{ subheading.content | safe }}</h3>{% endfor %}
{% if analysis.vulnerability.non_compliant %}<div class="columns"><div class="column analysis-type margin-top50"><a class="link-tag" id="{{ analysis.id }}{{ forloop.counter }}non_compliant"></a><h5>Noncompliant Code Example</h5></div></div><div class="margin-left35 margin-top20">{{ analysis.vulnerability.non_compliant | safe }}</div>{% endif %}
{% if analysis.vulnerability.compliant %}<div class="columns"><div class="column analysis-type margin-top50"><a class="link-tag" id="{{ analysis.id }}{{ forloop.counter }}compliant"></a><h5>Compliant Solution</h5></div></div><div class="margin-left35 margin-top20 margin-bottom50">{{ analysis.vulnerability.compliant | safe }}</div>{% endif %}
{% if analysis.vulnerability.business_implication %}<div class="columns"><div class="column analysis-type margin-top50"><a class="link-tag" id="{{ analysis.id }}{{ forloop.counter }}related_to"></a><h5>Related Vulnerabilities</h5></div></div><div class="margin-left35 margin-top20 margin-bottom50">{{ analysis.vulnerability.related_to | safe }}</div>{% endif %}
{% if analysis.vulnerability.business_implication %}<div class="columns"><div class="column analysis-type margin-top50"><a class="link-tag" id="{{ analysis.id }}{{ forloop.counter }}business_implication"></a><h5>Business Implication</h5></div></div><div class="margin-left35 margin-top20 margin-bottom50">{{ analysis.vulnerability.business_implication | safe }}</div>{% endif %}</section>{% endif %}
{% endfor %}</div></div></body></html>